require 'redmine'
require_dependency 'boards_watchers_patches'
require 'dispatcher'

unless Redmine::Plugin.registered_plugins.keys.include?(:redmine_boards_watchers)
  Redmine::Plugin.register :redmine_boards_watchers do
    name 'Extended watchers management and sticky priority levels add-on'
    author 'Vitaly Klimov'
    author_url 'mailto:vitaly.klimov@snowbirdgames.com'
    description 'Plugin creates three levels of sticky messages and allows managing of forums/topics/wikis watchers'
    version '0.2.1'
    requires_redmine :version_or_higher => '1.3.0'

    project_module :boards do
      permission :delete_board_watchers, {:boards_watchers => [:manage] }, :require => :member
      permission :delete_message_watchers, {:boards_watchers => [:manage_topic, :manage_topic_remote] }, :require => :member
    end

    project_module :wiki do
      permission :delete_wiki_watchers, {:boards_watchers => [:manage_wiki] }, :require => :member
    end
  end

  require 'boards_watchers_hooks'
end

Dispatcher.to_prepare :redmine_boards_watchers do
  require_dependency 'application_helper' if ENV['RAILS_ENV'] == 'production'
  require 'message'

  unless Message.included_modules.include? BoardsWatchers::Patches::StickyPriorityMessagePatch
    Message.send(:include, BoardsWatchers::Patches::StickyPriorityMessagePatch)
  end
  if ENV['RAILS_ENV'] == 'production'
    unless ApplicationHelper.included_modules.include? BoardsWatchers::Patches::ApplicationHelperPatch
      ApplicationHelper.send(:include, BoardsWatchers::Patches::ApplicationHelperPatch)
    end
  end
end


